/***************************************************************************
 *   Copyright (C) 2003 by Stephen Allewell                                *
 *   stephen@mirramar.fsnet.co.uk                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include <qpainter.h>
#include <kdebug.h>
#include "preview.h"
#include "kxstitchview.h"
#include "kxstitchdoc.h"

PreView::PreView(KXStitchDoc* doc, QWidget* parent)
  : QScrollView(parent),
    m_doc(doc)
{
  setVScrollBarMode(AlwaysOff);
  setHScrollBarMode(AlwaysOff);
  resizeContents(0,0);
  setBackgroundMode(PaletteBackground);
}

void PreView::setVisibleCells(QRect cells)
{
  m_visible = cells;
  viewport()->repaint(false);
}

void PreView::contentsMousePressEvent(QMouseEvent* e)
{
  m_point = e->pos();
  m_moved = false;
  setCursor(sizeAllCursor);
}

void PreView::contentsMouseMoveEvent(QMouseEvent* e)
{
  QPoint p = e->pos();
  m_moved = true;
  if (p != m_point)
  {
    int dx = m_point.x()-p.x();
    int dy = m_point.y()-p.y();
    scrollBy(dx,dy);
  }
}

void PreView::contentsMouseReleaseEvent(QMouseEvent*)
{
  setCursor(arrowCursor);
  if (!m_moved)
    emit clicked(QPoint(m_point.x()/2,m_point.y()/2)); // stitch coordinate
}

void PreView::drawContents(QPainter* p, int, int, int, int)
{
  QPixmap* pixmap = m_doc->m_preview;
  resizeContents(pixmap->width(), pixmap->height());
  p->drawPixmap(QPoint(0,0),*pixmap);
  if (m_visible.width() < pixmap->width() || m_visible.height() < pixmap->height())
    p->drawRect(m_visible.left()*2, m_visible.top()*2, m_visible.width()*2, m_visible.height()*2);
}
